@@ -1,7 +1,10 @@
 use windows_sys::Win32::UI::WindowsAndMessaging::*;
 use nxui::messagebox;
+use nxui::NativesAndMessaging::*;
+
+extern crate gtk;
 
 fn main() {
     let msg_box = messagebox::MessageBox { title: "This is a test".to_string(), message: "Hello World".to_string() };
-    msg_box.show(MB_OK);
+    msg_box.show(BUTTONSTYLE_OK,WINDOWSTYLE_MODAL);
 }
\ No newline at end of file
