@@ -14,7 +14,6 @@ impl MessageBox {
         &self.message
     }
 
-    #[cfg(windows)]
     /// Display the dialog
     ///
     /// # Examples
@@ -22,13 +21,15 @@ impl MessageBox {
     /// ```
     /// use windows_sys::Win32::UI::WindowsAndMessaging::*;
     /// use nxui::messagebox;
+    /// use nxui::NativesAndMessaging::*;
     ///
     /// fn main() {
     ///     let msg_box = messagebox::MessageBox { title: "This is a test".to_string().parse().unwrap(), message: "Hello World".to_string().parse().unwrap() };
-    ///     msg_box.show(MB_OK);
+    ///     msg_box.show(BUTTONSTYLE_OK,WINDOWSTYLE_MODAL);
     /// }
     /// ```
-    pub fn show(&self,button_type: MESSAGEBOX_STYLE) {
+    #[cfg(windows)]
+    pub fn show(&self,button_type: MESSAGEBOX_STYLE,window_style: u64) {
         use windows_sys::{
             Win32::Foundation::*, Win32::System::Threading::*, Win32::UI::WindowsAndMessaging::*,
         };
@@ -38,7 +39,20 @@ impl MessageBox {
             WaitForSingleObject(event, 0);
             CloseHandle(event);
 
-            MessageBoxA(0, self.message.as_ptr(), self.title.as_ptr(), MB_OK);
+            MessageBoxA(window_style.try_into().unwrap(), self.message.as_ptr(), self.title.as_ptr(), button_type);
         }
     }
+    #[cfg(linux)]
+    pub fn show(&self,button_type: ButtonsType,window_style: DialogFlags) {
+        use gtk::prelude::*;
+        let dialog = gtk::MessageDialog::new(
+            Some(&window_),
+            window_style,
+            gtk::MessageType::Info,
+            button_type
+            &message
+        );
+        dialog.run();
+        dialog.destroy();
+    }
 }
\ No newline at end of file
